==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/gui/buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	buttons.lang.inc.php 2019-06-07
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'abort'             => 'Abbrechen',
	'active'            => 'Aktiv',
	'add'               => 'Hinzufügen',
	'address_change'    => 'Adresse ändern',
	'add_to_cart'       => 'In den Warenkorb',
	'view_article'      => 'Zum Artikel',
	'add_to_wishlist'   => 'Auf den Merkzettel',
	'apply'             => 'Übernehmen',
	'back'              => 'Zurück',
	'back_small'        => 'zurück',
	'buy_as_guest'      => 'Als Gast bestellen',
	'cancel'            => 'Abbrechen',
	'canel'             => 'Abbrechen',
	'checkout'          => 'Kasse',
	'click_here'        => 'Gambio Admin',
	'close'             => 'Schließen',
	'continue'          => 'Weiter',
	'continue_shopping' => 'Weiter einkaufen',
	'create'            => 'Erstellen',
	'delete'            => 'Löschen',
	'download'          => 'Download',
	'edit'              => 'Bearbeiten',
	'edit_category'     => 'Kategorie bearbeiten',
	'edit_content'      => 'Content bearbeiten',
	'edit_product'      => 'Produkt bearbeiten',
	'execute'           => 'Ausführen',
	'go'                => 'Los',
	'inactive'          => 'Inaktiv',
	'install'           => 'Installieren',
	'installed'         => 'Installiert',
	'login'             => 'Anmelden',
	'new_address'       => 'Neue Adresse',
	'new_mail'          => 'Neue E-Mail',
	'next_small'        => 'vor',
	'next'              => 'Weiter',
	'no'                => 'Nein',
	'ok'                => 'Ok',
	'print'             => 'Drucken',
	'redeem'            => 'Einlösen',
	'refresh'           => 'Aktualisieren',
	'register'          => 'Daten eingeben',
	'save'              => 'Speichern',
	'search'            => 'Suchen',
	'send'              => 'Senden',
	'send_order'        => 'Kostenpflichtig bestellen',
	'show'              => 'anzeigen',
	'to_cart'           => 'Zum Warenkorb',
	'to_the_product'    => 'Zum Artikel',
	'uninstall'         => 'Deinstallieren',
	'uninstalled'       => 'Deinstalliert',
	'update'            => 'Aktualisieren',
	'yes'               => 'Ja',
	'your_opinion'      => 'Ihre Meinung',
	'forward'           => 'Weiterleiten',
	'preview'           => 'Ansehen',
	'queue'             => 'Speichern'
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/gui/buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	buttons.lang.inc.php 2020-10-06
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'abort'             => 'Abbrechen',
	'active'            => 'Aktiv',
	'add'               => 'Hinzufügen',
	'address_change'    => 'Adresse ändern',
	'add_to_cart'       => 'In den Warenkorb',
	'view_article'      => 'Zum Artikel',
	'add_to_wishlist'   => 'Auf den Merkzettel',
	'apply'             => 'Übernehmen',
	'back'              => 'Zurück',
	'back_small'        => 'zurück',
	'buy_as_guest'      => 'Als Gast bestellen',
	'cancel'            => 'Abbrechen',
	'canel'             => 'Abbrechen',
	'checkout'          => 'Kasse',
    'checkout_disabled' => 'Bitte Mindest-/Höchstbestellwert beachten.',
	'click_here'        => 'Gambio Admin',
	'close'             => 'Schließen',
	'continue'          => 'Weiter',
	'continue_shopping' => 'Weiter einkaufen',
	'create'            => 'Erstellen',
	'delete'            => 'Löschen',
	'download'          => 'Download',
	'edit'              => 'Bearbeiten',
	'edit_category'     => 'Kategorie bearbeiten',
	'edit_content'      => 'Content bearbeiten',
	'edit_product'      => 'Produkt bearbeiten',
	'execute'           => 'Ausführen',
	'go'                => 'Los',
	'inactive'          => 'Inaktiv',
	'install'           => 'Installieren',
	'installed'         => 'Installiert',
	'login'             => 'Anmelden',
	'new_address'       => 'Neue Adresse',
	'new_mail'          => 'Neue E-Mail',
	'next_small'        => 'vor',
	'next'              => 'Weiter',
	'no'                => 'Nein',
	'ok'                => 'Ok',
	'print'             => 'Drucken',
	'redeem'            => 'Einlösen',
	'refresh'           => 'Aktualisieren',
	'register'          => 'Daten eingeben',
	'save'              => 'Speichern',
	'search'            => 'Suchen',
	'send'              => 'Senden',
	'send_order'        => 'Kostenpflichtig bestellen',
	'show'              => 'anzeigen',
	'to_cart'           => 'Zum Warenkorb',
	'to_the_product'    => 'Zum Artikel',
	'uninstall'         => 'Deinstallieren',
	'uninstalled'       => 'Deinstalliert',
	'update'            => 'Aktualisieren',
	'yes'               => 'Ja',
	'your_opinion'      => 'Ihre Meinung',
	'forward'           => 'Weiterleiten',
	'preview'           => 'Ansehen',
	'queue'             => 'Speichern',
    'open'              => 'Aufrufen'
];
